@@ -38,7 +38,7 @@ __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 
 __license__: str = "MIT License"
-__version__: str = "0.2.3"
+__version__: str = "0.2.6"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __version_full__ = __version__
@@ -51,7 +51,7 @@ class HTML5Translator(sphinx.writers.html5.HTML5Translator):
 	Custom :class:`sphinx.writers.html5.HTML5Translator` to adjust spacing in bullet pointed lists.
 	"""
 
-	def visit_bullet_list(self, node: Element) -> None:
+	def visit_bullet_list(self, node: Element) -> None:  # noqa: D102
 		if len(node) == 1 and isinstance(node[0], addnodes.toctree):
 			# avoid emitting empty <ul></ul>
 			raise nodes.SkipNode
@@ -66,36 +66,36 @@ class HTML5Translator(sphinx.writers.html5.HTML5Translator):
 		classes = []
 
 		if self.compact_simple and not old_compact_simple:
-			classes.append('simple')
+			classes.append("simple")
 
 		if any(len(child) > 1 for child in node):
-			classes.append('expanded')
+			classes.append("expanded")
 
 		if classes:
-			atts["class"] = " ".join(classes)
+			atts["class"] = ' '.join(classes)
 
-		self.body.append(self.starttag(node, 'ul', **atts))
+		self.body.append(self.starttag(node, "ul", **atts))
 
-	def visit_enumerated_list(self, node):
+	def visit_enumerated_list(self, node):  # noqa: D102
 		atts = {}
 		classes = []
 
-		if 'start' in node:
-			atts['start'] = node['start']
+		if "start" in node:
+			atts["start"] = node["start"]
 
-		if 'enumtype' in node:
-			classes.append(node['enumtype'])
+		if "enumtype" in node:
+			classes.append(node["enumtype"])
 
 		if self.is_compactable(node):
-			classes.append('simple')
+			classes.append("simple")
 
 		if any(len(child) > 1 for child in node):
-			classes.append('expanded')
+			classes.append("expanded")
 
 		if classes:
-			atts["class"] = " ".join(classes)
+			atts["class"] = ' '.join(classes)
 
-		self.body.append(self.starttag(node, 'ol', **atts))
+		self.body.append(self.starttag(node, "ol", **atts))
 
 
 def setup(app: Sphinx):
